SphericalHarmonics
------------------

.. automodule:: spharpy.classes.sh

**Classes:**

.. autosummary::

   SphericalHarmonicDefinition
   SphericalHarmonics

.. autoclass:: spharpy.SphericalHarmonicDefinition
   :members:
   :undoc-members:
   :inherited-members:

.. autoclass:: spharpy.SphericalHarmonics
   :members:
   :undoc-members:
   :inherited-members:
